@@ -31,7 +31,7 @@ FILE_FORMATS = {
         '.mp3', '.flac', '.wav', '.m4a'
     },
     'Other': {
-        '.json', '.torrent', '.zip', '.rar', '.7z', '.torrent'
+        '.json', '.torrent', '.zip', '.rar', '.7z', '.torrent', '.psd'
     }
 }
 
@@ -40,6 +40,16 @@ MAX_FILENAME_LENGTH = 100
 logger = logging.getLogger(__name__)
 
 
+class FailureException(Exception):
+    """Basic failure exception I can throw to force a retry."""
+
+    def __init__(self, code, message="Something went wrong"):
+        self.code = code
+        self.message = message
+        super().__init__(self.message)
+        super().__init__(self.code)
+
+
 async def sanitize(name: str) -> str:
     return re.sub(r'[<>:"/\\|?*\']', "", name).strip()
 
@@ -99,7 +109,7 @@ async def write_last_post_file(file: Path, url: str):
 
 async def check_direct(url: URL):
     mapping_direct = ['i.pixl.is', r's..putmega.com', r's..putme.ga', r'img-...cyberdrop...', r'f.cyberdrop...',
-                      r'fs-...cyberdrop...', r'cdn.bunkr...', r'cdn..bunkr...', r'media-files.bunkr...',
+                      r'fs-...cyberdrop...', r'i.bunkr...', r'i..bunkr...', r'i...bunkr...', r'media-files.bunkr...',
                       r'media-files..bunkr...', r'jpg.church/images/...', r'simp..jpg.church']
     return any(re.search(domain, url.host) for domain in mapping_direct)
 
